#[non_exhaustive]pub struct ContractConfig {
pub exchange: Address,
pub collateral: Address,
pub conditional_tokens: Address,
pub neg_risk_adapter: Option<Address>,
}Expand description
Helper struct to group the relevant deployed contract addresses
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.exchange: Addresscollateral: Addressconditional_tokens: Addressneg_risk_adapter: Option<Address>The Neg Risk Adapter contract address. Only present for neg-risk market configs. Users must approve this contract for token transfers to trade in neg-risk markets.